import pytest

from ourobori.services.errors import prepare_exception_ctx
from ourobori.services.errors import InvalidInputException
from ourobori.services.errors import InvalidOutputException
from ourobori.services.errors import ServiceCallException
from ourobori.services.errors import ServiceNotAliveException
from ourobori.services.errors import DatabaseNotAliveException
from ourobori.services.errors import DatabaseTransactionException
from ourobori.services.errors import HostCmdException
from ourobori.services.errors import HostConnectionException
from ourobori.services.errors import HostSCPFromException
from ourobori.services.errors import HostSCPToException


@pytest.mark.parametrize('exception_class',
                         [InvalidInputException,
                          InvalidOutputException,
                          ServiceCallException,
                          ServiceNotAliveException,
                          DatabaseNotAliveException,
                          DatabaseTransactionException,
                          HostCmdException,
                          HostConnectionException,
                          HostSCPFromException,
                          HostSCPToException])
def test_exception(exception_class):
    with pytest.raises(exception_class):
        raise exception_class



@pytest.mark.parametrize(
    'exception_class, exception_params',
    [(InvalidInputException, dict()),
     (InvalidOutputException, dict()),
     (ServiceCallException, dict(name='test',
                                 api='example',
                                 params=dict(),
                                 err='testerr')),
     (ServiceNotAliveException, dict(name='test')),
     (DatabaseNotAliveException, dict(name='test',
                                      dsn='bla@blub')),
     (DatabaseTransactionException, dict(name='test',
                                         transaction='hgwkhg',
                                         err='testerr')),
     (HostCmdException, dict(name='test',
                             cmd='echo "blub"',
                             err='testerr')),
     (HostSCPFromException, dict(name='test',
                                 err='testerr')),
     (HostSCPToException, dict(name='test',
                               err='testerr')),
     (HostConnectionException, dict(name='test',
                                    err='testerr'))
     ])
def test_prepare_exception_ctx(exception_class, exception_params):
    with pytest.raises(exception_class):
        exc = prepare_exception_ctx(exception_class=exception_class,
                                    exception_params=exception_params)
        raise exc
