from pathlib import Path

from attr.exceptions import FrozenInstanceError
import pytest

from ourobori.docs.swagger import Contact
from ourobori.docs.swagger import License
from ourobori.services.rules import BaseRules


@pytest.fixture()
def dummy_rules():
    rules = BaseRules(servicename='testservice',
                      port=50000,
                      version='0.0.1',
                      description='example description',
                      contact=Contact(name='Simon Kallfass',
                                      email='bla@blub.com',
                                      url='http://bla.com'),
                      logfile=Path(),
                      hostname='localhost',
                      license=License(name='MIT',
                                      url='http://bla.com'),)
    return rules



def test_immutable_rules(dummy_rules):
    with pytest.raises(FrozenInstanceError):
        dummy_rules.servicename = 'blubservice'


@pytest.mark.parametrize(
    'attribute',
    ['servicename',
     'port',
     'version',
     'description',
     'contact',
     'logfile',
     'hostname',
     'license',
     'auths',
     'logstash_conn',
     'apidoc_location',
     'client_apidoc_location',
     'handle_exceptions']
)
def test_attributes_available(attribute, dummy_rules):
    getattr(dummy_rules, attribute)
